/*
 * $Id: XSSInterceptor.java 2 2010-06-27 16:53:19Z samaxes $
 *
 * Copyright 2010 samaxes.com
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.samaxes.stripes.xss;

import javax.servlet.http.HttpServletRequest;

import net.sourceforge.stripes.action.Resolution;
import net.sourceforge.stripes.controller.ExecutionContext;
import net.sourceforge.stripes.controller.Interceptor;
import net.sourceforge.stripes.controller.Intercepts;
import net.sourceforge.stripes.controller.LifecycleStage;
import net.sourceforge.stripes.controller.StripesRequestWrapper;

/**
 * <p>
 * An {@code Interceptor} that sanitizes all the request parameters before allowing the ActionBean resolution to
 * proceed.
 * </p>
 * 
 * <p>
 * To configure {@code XSSInterceptor}, add the following initialization parameters to your Stripes filter configuration
 * in <code>web.xml</code>:
 * </p>
 * 
 * <p>
 * 
 * <pre>
 * &lt;init-param&gt;
 *     &lt;param-name&gt;Interceptor.Classes&lt;/param-name&gt;
 *     &lt;param-value&gt;
 *         com.samaxes.stripes.xss.XSSInterceptor
 *     &lt;/param-value&gt;
 * &lt;/init-param&gt;
 * </pre>
 * 
 * </p>
 * 
 * <p>
 * If one or more interceptors are already configured in your <code>web.xml</code> simply separate the fully qualified
 * names of the interceptors with commas and place this interceptor as the last param value in the existing list.
 * </p>
 * 
 * @author Samuel Santos
 * @version $Revision: 26 $
 */
@Intercepts(LifecycleStage.BindingAndValidation)
public class XSSInterceptor implements Interceptor {

    private static ThreadLocal<ExecutionContext> currentContext = new ThreadLocal<ExecutionContext>();

    /**
     * Sanitize all the request parameters before allowing the ActionBean resolution to proceed.
     * 
     * @param context the current execution context
     * @return the Resolution produced by calling context.proceed()
     * @throws Exception if the lifecycle code or one of the interceptors throws one
     */
    public Resolution intercept(ExecutionContext context) throws Exception {
        StripesRequestWrapper stripesWrapper = null;
        HttpServletRequest originalRequest = null;

        try {
            currentContext.set(context);
            stripesWrapper = StripesRequestWrapper.findStripesWrapper(context.getActionBeanContext().getRequest());
            originalRequest = (HttpServletRequest) stripesWrapper.getRequest();
            stripesWrapper.setRequest(new XssRequestWrapper(originalRequest));
            return context.proceed();
        } finally {
            currentContext.remove();
            if (stripesWrapper != null && originalRequest != null) {
                stripesWrapper.setRequest(originalRequest);
            }
        }
    }
}
